![Title](docs/Images/scikit_sound.png)
============
scikit-sound
============

*scikit-sound* contains functions for working with sound 

Dependencies
------------

numpy, scipy

Homepage
--------

<http://work.thaslwanter.at/sksound/html/>

Author: Thomas Haslwanter Date: 08-10-2024 Ver: 0.3.0 Licence: BSD
2-Clause License (<http://opensource.org/licenses/BSD-2-Clause>)
Copyright (c) 2024, Thomas Haslwanter All rights reserved.

Installation
------------

You can install scikit-sound with

> pip install scikit-sound

and upgrade to a new version with

> pip install scikit-sound -U

Sound Processing Utilities
==========================

- sounds.Sound ... class, with methods
    * generate_sound
    * get_info
    * play
    * read_sound
    * summary
    * write_wav

Misc Other Utilities
====================

- misc ... GUI routines for standard file- and directory-handling
   * askquestion
   * get_dir
   * get_file
   * progressbar
   * save_file
